/**
 * @name jquery.esia.bar.js
 * @description Propose des fonctions pour afficher des camemberts, y ajouter des infobules et les rendre clickable
 * @author George Julien <j.george@esia-sa.com>
 * @contributor
 * @copyright Nicolas Biersart 2012
 * @license
 * @esia 1.00
 * @version 1.0.0
 * @date 25/02/2015
 */

/*@NAME: pie_view
*@IN:	elm 	l'élement div qui sera un camembert, peut être un id html, un élément DOM HTML javascript ou un selecteur jquery
		data	un tableau contenant des tableaux label, value des données.
@OUT: /
@TREAT: Affiche un camembert.
@EXCEPTION: 	/
*/
function pie_view(elm,data){
	if( elm instanceof HTMLElement 	){ elm.id; }
	else if( typeof elm != "string"	){ elm.get(0).id; }

	var plot1 = jQuery.jqplot (elm, [data], { 
		 grid:
		    {
		    drawBorder:false,
		    shadow:false,
		    },
		gridPadding:{top:0,right:0,bottom:0,left:0},
			      seriesDefaults: {
			        // Make this a pie chart.
			        renderer: jQuery.jqplot.PieRenderer,
			        rendererOptions: {
			          // Put data labels on the pie slices.
			          // By default, labels show the percentage of the slice.
			          showDataLabels: true,
			          padding:10,
			        	dataLabelThreshold: 1,//dataLabelPositionFactor:1.2,
			      		fill: true,lineWidth: 8,  dataLabels: 'value'
			        }
			      },
		seriesDefaults: {
        		renderer: jQuery.jqplot.PieRenderer, 
        		rendererOptions: { showDataLabels: true }
      	}, 
     	legend: { show:true, location: 'e' },
    });
}

/*@NAME: pie_click
*@IN:	elm 	le camembert, peut être un id html, un élément DOM HTML javascript ou un selecteur jquery
		urls	un tableau d'urls. L'urls[0] sera affiché à la donnée [0] et ainsi de suite.
@OUT: /
@TREAT: Rends le camembert clickable
@EXCEPTION: 	/
*/
function pie_click(elm,urls){
	if( elm instanceof HTMLElement 	){ elm = $(elm); }
	if( typeof elm == "string"	){ elm = $("#"+elm); }

	elm.bind('jqplotDataClick',
	function (ev, seriesIndex, pointIndex, data) {
		if(urls!=null&&urls[pointIndex]!=null){
			window.location.href = urls[pointIndex];
		}
	});
}

/*@NAME: pie_tooltip
*@IN:	elm 	le camembert, peut être un id html, un élément DOM HTML javascript ou un selecteur jquery
		tooltips	un tableau de strings correspondant à du code html. Le tooltips[0] sera affiché à la donnée [0] et ainsi de suite.
@OUT: /
@TREAT: Affiche des infobules sur les camemberts
@EXCEPTION: 	/
*/
function pie_tooltip(elm,tooltips){
	if( elm instanceof HTMLElement 	){ elm = $(elm); }
	if( typeof elm == "string"	){ elm = $("#"+elm); }

	elm.bind('jqplotDataHighlight', function(ev, seriesIndex, pointIndex, data) {
		var $this = $(this);         
		            
		$this.tooltip();                      
	//	$this.tooltip( "close" );

		if(tooltips!=null&&tooltips[pointIndex]!=null){
			$this.attr('title', tooltips[pointIndex] ); 	
			$this.tooltip("option","content", tooltips[pointIndex] );

			$this.tooltip( "option", "position", { my: "left+15 center", at: "right center" });				
			$this.tooltip( "open" );
		}
        }); 

	elm.bind('jqplotDataUnhighlight', function(ev, seriesIndex, pointIndex, data) {
        	var $this = $(this);       
	    	$this.tooltip( "close" );
	});
}
